<template>
  <div ref="cpuMenery" style="height:100%;"></div>
</template>

<script>
import echarts from "echarts";

export default {
  name: "eChartsCpu",
  props: {
    title: {
      type: String,
      defalut: ""
    },
    value: {
      type: Number,
      defalut: 0
    },
    yAxisData: {
      type: Array,
      default: () => {
        return ["硬盘", "CPU", "算力", "内存"]
      }
    },
    xAxisData: {
      type: Array,
      default: () => {
        return []
      }
    },
    width: {
      type: Number,
      default: 500
    },
    size: {
      type: Number,
      defalut: 145
    }
  },
  computed: {

  },
  data() {
    return {
      eChartsObj: {}
    }
  },
  mounted() {
    // console.log(this.$refs.cpuMenery.offsetWidth,'this.$refs.cpuMenery',this.$refs.cpuMenery.offsetHeight)
    if (this.$refs.cpuMenery.offsetWidth && this.$refs.cpuMenery.offsetHeight) {
      this.initChart()
    }
    window.addEventListener('resize', this.windowSizeChange)
  },
  watch: {
    value: function (newVal, oldVal) {
      if (newVal !== oldVal) {
        this.initChart()
      }
    }
  },
  methods: {
    initChart() {
      let options = {
        title: {
          // 标题
          text: this.title
        },
        tooltip: {
          formatter: (data) => {
            return data.value + '%'
          }
        },
        grid: {
          top: 10,
          right: 30,
          bottom: 20,
          left: 40,
        },
        xAxis: {
          show: false,
          type: 'value',
          max: 100,
          splitLine: {
            show: false
          },
          axisLine: {
            lineStyle: {
              color: '#dfe6ec'
            }
          },
          axisTick: {
            lineStyle: {
              color: '#606266'
            }
          },
          axisLabel: {
            color: '#606266'
          },
        },
        yAxis: {
          show: true,
          type: 'category',
          data: this.yAxisData,
          axisLabel: {
            interval: 0,
            rotate: 0
          },
          axisLine: {
            show: false,
            lineStyle: {
              color: '#dfe6ec'
            }
          },
          axisTick: {
            show: false,
            lineStyle: {
              color: '#606266'
            }
          },
          axisLabel: {
            color: '#606266',
            align: 'right'
          },
        },
        series: [
          {
            type: 'bar',
            stack: 'chart',
            z: 3,
            itemStyle: {
              normal: {
                color: '#3D68E1'
              },
              emphasis: {
                color: '#3D68E1'
              }
            },
            data: this.xAxisData,
            label: {
              show: true,
              position: 'right',
              formatter: (data) => {
                return data.value + '%'
              }
            },
          },
          {
            type: 'bar',
            stack: 'chart',
            silent: true,
            itemStyle: {
              normal: {
                color: 'rgb(248, 248, 248)'
              }
            },
            data: this.xAxisData.map(function (i) {
              return 100 - i;
            }),
            barMaxWidth: 15
          }
        ]
      }
      
      this.eChartsObj = echarts.init(this.$refs.cpuMenery);
      this.eChartsObj.setOption(options);
 
    },
    windowSizeChange() {
      this.eChartsObj.resize();
    }
  }
};
</script>
<style lang="scss">
</style>